@@ -10,16 +10,23 @@
     #define setutxent setutent
     #define getutxent getutent
 #endif
+#ifdef __linux__
+    #include <netinet/in.h>
+    #include <arpa/inet.h>
+#endif
 
-const char* ffDetectUsers(FFlist* users)
+const char* ffDetectUsers(FFUsersOptions* options, FFlist* users)
 {
     struct utmpx* n = NULL;
     setutxent();
 
 next:
-    while((n = getutxent()))
+    while ((n = getutxent()))
     {
-        if(n->ut_type != USER_PROCESS)
+        if (n->ut_type != USER_PROCESS)
+            continue;
+
+        if (options->myselfOnly && !ffStrbufEqualS(&instance.state.platform.userName, n->ut_user))
             continue;
 
         FF_LIST_FOR_EACH(FFUserResult, user, *users)
@@ -33,11 +40,11 @@ next:
         ffStrbufInitS(&user->hostName, n->ut_host);
         ffStrbufInitS(&user->sessionName, n->ut_line);
         #ifdef __linux__
-        if(n->ut_addr_v6[0] || n->ut_addr_v6[1] || n->ut_addr_v6[2] || n->ut_addr_v6[3])
-            ffStrbufInitF(&user->clientIp, "%u.%u.%u.%u", n->ut_addr_v6[0], n->ut_addr_v6[1], n->ut_addr_v6[2], n->ut_addr_v6[3]);
-        else
-        #endif
+        // https://www.linuxquestions.org/questions/programming-9/get-the-ip-addr-out-from-an-int32_t-value-287687/#post1458622
+        ffStrbufInitS(&user->clientIp, inet_ntoa((struct in_addr) { .s_addr = (in_addr_t) n->ut_addr_v6[0] }));
+        #else
         ffStrbufInit(&user->clientIp);
+        #endif
         user->loginTime = (uint64_t) n->ut_tv.tv_sec * 1000 + (uint64_t) n->ut_tv.tv_usec / 1000;
     }
 
